@@ -15,11 +15,11 @@ binmode( STDOUT, ":encoding(console_out)" );
 binmode( STDERR, ":encoding(console_out)" );
 
 my %opt;
-getopt( 'wsqkmbfrtiCSoTcRAFNPIMnUpvuBDgG', \%opt );
+getopt( 'usfwbtoqkDCvgGiANnrEpBIMm', \%opt );
 
 my %opt_out = read_option(%opt);
 our $xs = Novel::Robot->new( type => $opt_out{type}, site => $opt_out{site} );
-$opt_out{chapter_ids} = $xs->split_id_list( $opt{i} )  if($opt{i});
+
 
 my $info;
 my $items_ref;
@@ -67,24 +67,16 @@ sub read_option {
     my %opt_out = (
         board    => $opt{B},
         book     => $opt{u} ? decode( locale => $opt{u} ) : undef,
-        category => $opt{c}
-        ? [ split ',', decode( locale => $opt{c} ) ]
-        : undef,
         chapter_regex => $opt{r} ? decode( locale => $opt{r} ) : undef,
         max_process_num => $opt{p} // 1,
         only_poster     => $opt{A},
         output          => $opt{o},
-        packer_url      => $opt{S},
-        passwd          => $opt{P},
         query_keyword => $opt{k} ? decode( locale => $opt{k} ) : undef,
         query_type    => $opt{q} ? decode( locale => $opt{q} ) : undef,
-        remark        => $opt{R} ? decode( locale => $opt{R} ) : undef,
         select_menu   => $opt{E},
         site => $opt{s} || $opt{u} || $opt{b},
         step_chapter_num => $opt{n},
-        tag => $opt{T} ? [ split ',', decode( locale => $opt{T} ) ] : undef,
         type => $opt{t} || 'html',
-        usr => $opt{U},
         verbose  => $opt{v} // 1,
         with_toc => $opt{C} // 1,
         writer => $opt{w} ? decode( locale => $opt{w} ) : undef,
@@ -96,7 +88,7 @@ sub read_option {
     my ( $class, $item ) = $opt{b} ? qw/board item/ : qw/query item/;
     if ( $opt{I} ) {
         ( $opt_out{"min_${class}_page"}, $opt_out{"max_${class}_page"} ) =
-          split '-', $opt{I};
+          split_index($opt{I});
     }
 
     if ( $opt{M} ) {
@@ -105,8 +97,8 @@ sub read_option {
 
     # tiezi ->
     if ( $opt{i} ) {
-        @opt_out{qw/min_tiezi_page max_tiezi_page/}   = split '-', $opt{i};
-        @opt_out{qw/min_chapter_num max_chapter_num/} = split '-', $opt{i};
+        @opt_out{qw/min_tiezi_page max_tiezi_page/}   = split_index($opt{i});
+        @opt_out{qw/min_chapter_num max_chapter_num/} = split_index($opt{i});
     }
 
     $opt_out{max_tiezi_floor_num} = $opt{m};
@@ -151,3 +143,13 @@ sub get_novel_split {
         );
     }
 }
+
+sub split_index {
+    my ($s) = @_;
+    return ($s, $s) if($s=~/^\d+$/);
+    if($s=~/^\d*-\d*$/){
+        my ($min, $max) = split '-', $s;
+        return ($min, $max);
+    }
+    return;
+}
